# Changelog

All notable changes to this project will be documented here.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.1] - 2023-3-3

### Added

- MANIFEST.in file.

## [1.0.0] - 2023-3-3

### Added

- Everything.

[Unreleased]: https://github.com/duhby/elommr/compare/v1.0.2...master
[1.0.1]: https://github.com/duhby/elommr/releases/tag/v1.0.1
[1.0.0]: https://github.com/duhby/elommr/releases/tag/v1.0.0
